-- 
-- FarmingTablet - Button
-- 
-- @Interface: 1.4.4.0 1.4.4RC8
-- @Author: kevink98 
-- @Date: 10.06.2017
-- @Version: 1.1.0
-- 
-- @Support: http://ls-modcompany.com
-- @mCompanyInfo: http://mcompany-info.de/
-- 

FarmingTabletButton = {};
FarmingTabletButton.allButtons = {};
FarmingTabletButton.categorys = {};
FarmingTabletButton.allOverlays = {};

FarmingTabletButton.version = "1.1.0";
print("   [FarmingTablet - Button] load " .. tostring(FarmingTabletButton.version));

source(g_currentModDirectory.."ButtonActions.lua");

function FarmingTabletButton:newButton(name,category,x,y,xS,yS,hoverT,defaultT,activeT,useOwnFunc)
	local button = {};
	button.hover = false;
	button.name = name;
	button.visible = true;
	button.isActivated = true;
	
	if useOwnFunc then
		local nameHover = "onActiveHover"..name;
		local nameHoverDe = "onDeactiveHover"..name;
		button.onActiveHover = function(...) return ButtonActions[nameHover](...) end;
		button.onDeactiveHover = function(...) return ButtonActions[nameHoverDe](...) end;
	else
		button.onActiveHover = function(name) return self:onActiveHover(name) end;
		button.onDeactiveHover = function(name) return self:onDeactiveHover(name) end;
	end;
	
	local nameClick = "onActiveClick"..name;
	button.onActiveClick = function(...) return ButtonActions[nameClick](...) end;
	
	button.posXL = x;
	button.posYU = y;
	button.posXR = x+xS;
	button.posYO = y+yS;
	button.scaleX = xS;
	button.scaleY = yS;
	
	button.OverlayHover = hoverT or defaultT;
	button.OverlayDefault = defaultT;
	button.OverlayActivate = activeT;
	button.ActivateState = false;
	if (hoverT == nil and defaultT == nil) or (hoverT == nil and defaultT ~= nil and activeT ~= nil) or (hoverT ~= nil and defaultT ~= nil and activeT ~= nil) then
		button.noDrawButton = true;
	else
		button.noDrawButton = false;
	end;
	
	table.insert(FarmingTabletButton.categorys[category],button);
	table.insert(FarmingTabletButton.allButtons,button);
	return button;
end;

function FarmingTabletButton:newCategory(nameCategory)
	if FarmingTabletButton.categorys[nameCategory] == nil then
		FarmingTabletButton.categorys[nameCategory] = {};
	end;
end;

function FarmingTabletButton:addOverlays(overlays,nameO)
	if nameO == nil or nameO == false then
		for name,overlay in pairs(overlays) do
			FarmingTabletButton.allOverlays[name] = overlay;
		end;
	elseif nameO then
		FarmingTabletButton.allOverlays[nameO] = overlays;
	end;
end;

function FarmingTabletButton:getOverlay(name)
	return FarmingTabletButton.allOverlays[name]
end;

function FarmingTabletButton:drawButtonByCategory(categoryName)
	for _,button in pairs(FarmingTabletButton.categorys[categoryName]) do
		if button.visible then
			if not button.noDrawButton then
				if button.hover and FarmingTabletButton.allOverlays[button.OverlayHover] ~= nil then
					renderOverlay(FarmingTabletButton.allOverlays[button.OverlayHover], button.posXL,button.posYU,button.scaleX,button.scaleY);
				elseif FarmingTabletButton.allOverlays[button.OverlayDefault] ~= nil then
					renderOverlay(FarmingTabletButton.allOverlays[button.OverlayDefault], button.posXL,button.posYU,button.scaleX,button.scaleY);
				elseif button.ActivateState and FarmingTabletButton.allOverlays[button.OverlayActivate] ~= nil then
					renderOverlay(FarmingTabletButton.allOverlays[button.OverlayActivate], button.posXL,button.posYU,button.scaleX,button.scaleY);
				end;
			elseif button.OverlayActivate and button.OverlayHover == nil then
				if button.ActivateState then
					renderOverlay(FarmingTabletButton.allOverlays[button.OverlayActivate], button.posXL,button.posYU,button.scaleX,button.scaleY);
				elseif FarmingTabletButton.allOverlays[button.OverlayDefault] ~= nil then
					renderOverlay(FarmingTabletButton.allOverlays[button.OverlayDefault], button.posXL,button.posYU,button.scaleX,button.scaleY);
				end;
			elseif	button.OverlayActivate and button.OverlayHover ~= nil then
				if button.hover and FarmingTabletButton.allOverlays[button.OverlayHover] ~= nil then
					renderOverlay(FarmingTabletButton.allOverlays[button.OverlayHover], button.posXL,button.posYU,button.scaleX,button.scaleY);
				end;
				if button.ActivateState then
					renderOverlay(FarmingTabletButton.allOverlays[button.OverlayActivate], button.posXL,button.posYU,button.scaleX,button.scaleY);
				elseif FarmingTabletButton.allOverlays[button.OverlayDefault] ~= nil and not button.hover then
					renderOverlay(FarmingTabletButton.allOverlays[button.OverlayDefault], button.posXL,button.posYU,button.scaleX,button.scaleY);
				end;
			end;
		end;
	end;
end;

function FarmingTabletButton:checkClickByCategory(categoryName,posX,posY,buttonIsClick,isDown)
	if FarmingTabletButton.categorys[categoryName] ~= nil then
		for _,button in pairs (FarmingTabletButton.categorys[categoryName]) do
			if posX > button.posXL and posX < button.posXR and posY > button.posYU and posY < button.posYO and buttonIsClick == 1 and isDown and button.visible and button.isActivated then
				button.onActiveClick(button);
				return true;
			end;
		end;		
	end;
end;

function FarmingTabletButton:checkHoverByCategory(categoryName,posX,posY)
	for _,button in pairs (FarmingTabletButton.categorys[categoryName]) do
		if posX > button.posXL and posX < button.posXR and posY > button.posYU and posY < button.posYO and button.visible and button.isActivated then
			button.onActiveHover(button);
		else
			button.onDeactiveHover(button);
		end;
	end;
end;

function FarmingTabletButton:checkAppClick(posX,posY,buttonIsClick,isDown,positions,windowToOpen)
	if posX > positions.xL and posX < positions.xR and posY > positions.yU and posY < positions.yO and buttonIsClick == 1 and isDown then
		FarmingTablet:allAppsClose(windowToOpen);
	end;
end;

function FarmingTabletButton:onActiveHover(button) 
	button.hover = true;
end;

function FarmingTabletButton:onDeactiveHover(button) 
	button.hover = false;
end;